# 2010 August 18 by Joshua R. Davis

"""
This program demonstrates how to make textures and apply them to shapes. On any shape, the texture's colors are modulated (tinted) by the shape's color. If you prefer not to tint the texture at all, then set the color to white.
"""

import bopagopa.bopagopajr as jr

if __name__ == "__main__":
	# All Bopagopa programs begin by creating a window.
	window = jr.WindowJr()
	# Make some textures by loading from image files.
	jdavisTexture = jr.makeFileTexture("128jdavis.jpg")
	fragmentTexture = jr.makeFileTexture("256fragment.png")
	# Make a rectangle with the fragment texture.
	rectangle = jr.makeRectangle(64.0, 128.0)
	rectangle.setPosition((64.0, 256.0))
	rectangle.setTexture(fragmentTexture)
	window.appendBody2D(rectangle)
	# Make an annulus with the jdavis texture.
	annulus = jr.makeAnnulus(32.0, 48.0)
	annulus.setTexture(jdavisTexture)
	annulus.setPosition((160.0, 422.0))
	window.appendBody2D(annulus)
	# Make a yellow rounded rectangle with the jdavis texture.
	roundedRectangle = jr.makeRoundedRectangle(64.0, 96.0, 8.0)
	roundedRectangle.setColor((1.0, 1.0, 0.0, 0.5))
	roundedRectangle.setTexture(jdavisTexture)
	roundedRectangle.setPosition((160.0, 90.0))
	window.appendBody2D(roundedRectangle)
	# Make a magenta polygon without texture; not everything has to have a texture.
	vertices = ((41.0, 5.0), (20.0, 50.0), (-70.0, 10.0), (-10.0, -60.0), (30.0, -30.0))
	polygon = jr.makeConvexPolygon(vertices)
	polygon.setColor((1.0, 0.0, 1.0, 0.9))
	polygon.setPosition((352.0, 90.0))
	window.appendBody2D(polygon)
	# All Bopagopa programs end by running the user interface.
	jr.beginUserInterface()
