# 2010 July 7 by Joshua R. Davis

"""
This program demonstrates how to construct a group of shapes that act as a rigid body, as if the shapes are glued together. The individual shapes are no longer attached to the window; rather, they are attached to the group, which is attached to the window. The individual shapes' positions, angles, and scales are all relative to the group's. Each shape within a group maintains its own color and texture as usual. The user interface handlers treat each group as a single object.
"""

import bopagopa.bopagopajr as jr
import math
import random

def handleClick(xy, name):
	"""Prints which shape was clicked. Notice that a child shape is considered part of its parent, because the child isn't directly attached to the window renderer itself."""
	print "Mouse click on body " + str(name) + "."

if __name__ == "__main__":
	# All Bopagopa programs begin by creating a window.
	window = jr.WindowJr()
	window.setClickHandler2D(handleClick)
	# Make the exhaust plume.
	plume = jr.makeConvexPolygon([(0.0, 0.0), (0.0, 32.0), (-32.0, 16.0)])
	plume.setColor((0.8, 0.8, 1.0, 0.5))
	plume.setPosition((-32.0, -16.0))
	# Make the propulsion system.
	rectangle = jr.makeRectangle(16.0, 32.0)
	rectangle.setColor((0.8, 0.8, 0.8, 1.0))
	rectangle.setPosition((-24.0, 0.0))
	# Make the left wing.
	left = jr.makeConvexPolygon([(0.0, 0.0), (23.0, 0.0), (0.0, 23.0)])
	left.setColor((0.8, 0.8, 0.8, 1.0))
	left.setPosition((0.0, 23.0))
	# Make the right wing.
	right = jr.makeConvexPolygon([(0.0, 0.0), (0.0, -23.0), (23.0, 0.0)])
	right.setColor((0.8, 0.8, 0.8, 1.0))
	right.setPosition((0.0, -23.0))
	# Make the fuselage.
	disk = jr.makeDisk(32.0)
	disk.setColor((0.8, 0.8, 0.8, 1.0))
	# Make the windscreen.
	sector = jr.makeSector(24.0, -math.pi / 4.0, math.pi / 4.0)
	sector.setColor((0.0, 0.0, 0.1, 1.0))
	# Combine these spaceship parts into a group.
	group = jr.Group2D([plume, rectangle, left, right, disk, sector])
	group.setPosition((256.0, 256.0))
	window.appendBody2D(group)
	# Make some asteroids.
	moonTexture = jr.makeFileTexture("256moon.jpg")
	for i in range(5):
		asteroid = jr.makeDisk(random.random() * 40.0 + 10.0)
		asteroid.setPosition((random.random() * 512.0, random.random() * 512.0))
		asteroid.setColor((0.5, 0.5, 0.5, 1.0))
		asteroid.setTexture(moonTexture)
		window.appendBody2D(asteroid)
	# All Bopagopa programs end by running the user interface.
	jr.beginUserInterface()
