# 2010 October 3 by Joshua R. Davis

"""
This tutorial demonstrates how to wrap textures around solids. The process is identical to that of slapping textures on shapes. This tutorial also shows how shapes (2D bodies) form an "overlay" layer above the scene of solids (3D bodies).
"""

import bopagopa.bopagopajr as jr

if __name__ == "__main__":
	# All Bopagopa programs begin by creating a window.
	window = jr.WindowJr()
	# Make some lights.
	light = jr.Light()
	window.setLights((light,))
	# Make some textures by loading from image files.
	jdavisTexture = jr.makeFileTexture("128jdavis.jpg")
	fragmentTexture = jr.makeFileTexture("256earth.jpg")
	# Make some 2D overlays.
	disk = jr.makeDisk(64.0)
	disk.setColor((1.0, 0.0, 0.0, 0.75))
	disk.setPosition((100.0, 200.0))
	window.appendBody2D(disk)
	rectangle = jr.makeRectangle(90.0, 70.0)
	rectangle.setTexture(fragmentTexture)
	rectangle.setPosition((300.0, 100.0))
	window.appendBody2D(rectangle)
	# Make some 3D bodies.
	box = jr.makeBox(10.0, 10.0, 1.0)
	box.setColor((0.0, 1.0, 0.0))
	box.setPosition((0.0, 0.0, -1.0))
	window.appendBody3D(box)
	sphere = jr.makeSphere(1.0)
	#sphere.setColor((1.0, 1.0, 0.0))
	sphere.setTexture(fragmentTexture)
	window.appendBody3D(sphere)
	cylinder = jr.makeCylinder(1.0, 0.5)
	cylinder.setColor((0.0, 0.0, 1.0))
	cylinder.setPosition((1.0, 0.0, 1.0))
	cylinder.setTexture(jdavisTexture)
	window.appendBody3D(cylinder)
	capsule = jr.makeCapsule(1.0, 0.5)
	capsule.setColor((1.0, 0.0, 1.0))
	capsule.setPosition((0.0, 1.0, 1.0))
	window.appendBody3D(capsule)
	cone = jr.makeCone(1.0, 0.5)
	cone.setColor((1.0, 0.5, 0.0))
	cone.setPosition((1.0, 1.0, 1.0))
	cone.setTexture(fragmentTexture)
	window.appendBody3D(cone)
	# All Bopagopa programs end by running the user interface.
	jr.beginUserInterface()
