# 2010 September 11 by Joshua R. Davis

"""
This program is like earlier user inteface tutorials, but with multiple windows going. This area of Bopagopa is not particularly well-developed or well-tested, but it seems to work. Each window maintains its own graphics, dynamics, and user interface, independent of the other windows. The Bopagopa function getWindow returns the current window --- that is, the one that's topmost, receiving user interface events.

Warning: When a Bopagopa Body3D or Camera is created, it is created in a particular ODE World. By default, it is created in the world belonging to the current window. Even if the body or camera is added to another window, its dynamics will still take place in that original world. The only flexibility you have is to pass a world of your choice when creating the Body3D or Camera.
"""

import bopagopa.bopagopajr as jr
import OpenGL.GLUT as glut
import math

def handleKeyboard(xy, key):
	"""Translates and rotates shape 0."""
	shape = jr.getWindow().getBodies2D()[0]
	if key == glut.GLUT_KEY_LEFT:
		shape.translate((-10.0, 0.0))
	elif key == glut.GLUT_KEY_RIGHT:
		shape.translate((10.0, 0.0))
	elif key == glut.GLUT_KEY_DOWN:
		shape.translate((0.0, -10.0))
	elif key == glut.GLUT_KEY_UP:
		shape.translate((0.0, 10.0))
	elif key == '1':
		shape.rotate(math.pi / 12.0)
	elif key == '2':
		shape.rotate(-math.pi / 12.0)
	# Inform the window that it needs to redraw itself.
	jr.getWindow().needsRedrawing()

def handleClick(xy, name):
	"""Inverts the color of the shape that was clicked."""
	# Use the name to get the Shape object itself.
	shape = jr.getWindow().getBodies2D()[name]
	# Invert the shape's color.
	color = shape.getColor()
	shape.setColor((1.0 - color[0], 1.0 - color[1], 1.0 - color[2], color[3]))
	# Inform the window that it needs to redraw itself.
	jr.getWindow().needsRedrawing()

def handleEndDrag(xyStarting, xyPrevious, xyFinal, name):
	"""When a shape stops being dragged, it reports its position."""
	# Use the name to get the shape object itself.
	shape = jr.getWindow().getBodies2D()[name]
	# Print out some fascinating information.
	print "The drag started at " + str(xyStarting) + " and ended at " + str(xyFinal) + "."
	print "The shape's final position is " + str(shape.getPosition()) + "."
	# The window does not need to redraw itself.

def handleMenu(itemName):
	"""A contextual menu has been attached to the right mouse button; when the user selects an item from this menu, its name (a string) is passed to this function, which prints it out."""
	print itemName

if __name__ == "__main__":
	# All Bopagopa programs begin by creating a window.
	window = jr.WindowJr()
	# Register the three event handlers defined above.
	window.setKeyboardHandler(handleKeyboard)
	window.setClickHandler2D(handleClick)
	window.setEndDragHandler2D(handleEndDrag)
	window.setMenuHandler(handleMenu, ["Pesto", "Corn", "Peaches"])
	# Make a red disk, scaled by 1.3 in the horizontal direction.
	disk = jr.makeDisk(32.0)
	disk.setColor((1.0, 0.0, 0.0, 0.9))
	disk.setPosition((448.0, 256.0))
	disk.setScales((1.3, 1.0))
	window.appendBody2D(disk)
	# Make a yellow sector.
	sector = jr.makeSector(48.0, 0.0, (2.0 / 3.0) * math.pi)
	sector.setColor((1.0, 1.0, 0.0, 0.9))
	sector.setPosition((352.0, 422.0))
	window.appendBody2D(sector)
	# Make an green annulus.
	annulus = jr.makeAnnulus(24.0, 48.0)
	annulus.setColor((0.0, 1.0, 0.0, 0.9))
	annulus.setPosition((160.0, 422.0))
	window.appendBody2D(annulus)
	# Now let's make another window to hold the rest of the shapes.
	window = jr.WindowJr()
	window.setKeyboardHandler(handleKeyboard)
	window.setClickHandler2D(handleClick)
	window.setEndDragHandler2D(handleEndDrag)
	window.setMenuHandler(handleMenu, ["Red", "Green", "Blue"])
	# Make a cyan rectangle, rotated pi / 6 = 30 degrees counterclockwise.
	rectangle = jr.makeRectangle(64.0, 32.0)
	rectangle.setColor((0.0, 1.0, 1.0, 0.9))
	rectangle.setPosition((64.0, 256.0))
	rectangle.rotate(math.pi / 6.0)
	window.appendBody2D(rectangle)
	# Make a blue rounded rectangle.
	roundedRectangle = jr.makeRoundedRectangle(64.0, 96.0, 8.0)
	roundedRectangle.setColor((0.0, 0.0, 1.0, 0.9))
	roundedRectangle.setPosition((160.0, 90.0))
	window.appendBody2D(roundedRectangle)
	# Make a magenta polygon.
	vertices = ((41.0, 5.0), (20.0, 50.0), (-70.0, 10.0), (-10.0, -60.0), (30.0, -30.0))
	polygon = jr.makeConvexPolygon(vertices)
	polygon.setColor((1.0, 0.0, 1.0, 0.9))
	polygon.setPosition((352.0, 90.0))
	window.appendBody2D(polygon)
	# All Bopagopa programs end by running the user interface.
	jr.beginUserInterface()
